| Title: | High Efficient Functions to Decode NFL Player IDs |
|---|---|
| Description: | A set of high efficient functions to decode identifiers of National Football League players. |
| Authors: | Sebastian Carl [aut, cre] |
| Maintainer: | Sebastian Carl <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1.9000 |
| Built: | 2026-05-12 07:01:35 UTC |
| Source: | https://github.com/nflverse/gsisdecoder |
This function is a wrapper around the high efficient c++ function for fast decoding of NFL GSIS player ids intended to be used within the R package nflfastR.
decode_ids(player_ids)decode_ids(player_ids)
player_ids |
A character vector of encoded (or decoded) GSIS player IDs
in NFL play-by-play data sets loaded with fast_scraper or
|
Decoded GSIS player IDs
# Decode IDs including already decoded ids and NA decode_ids(c( "32013030-2d30-3033-3338-3733fa30c4fa", NA_character_, "00-0033873", NA_character_, "32013030-2d30-3032-3739-3434d4d3846d" ))# Decode IDs including already decoded ids and NA decode_ids(c( "32013030-2d30-3033-3338-3733fa30c4fa", NA_character_, "00-0033873", NA_character_, "32013030-2d30-3032-3739-3434d4d3846d" ))